@@ -1,7 +1,7 @@
 package Perinci::Access::Simple::Server::Socket;
 
-our $DATE = '2015-09-12'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,7 +16,7 @@ use IO::Select;
 use IO::Socket qw(:crlf);
 use IO::Socket::INET;
 use IO::Socket::UNIX;
-use JSON;
+use JSON::MaybeXS;
 use Perinci::Access;
 use Perinci::AccessUtil qw(insert_riap_stuffs_to_res decode_args_in_riap_req);
 use Proc::Daemon::Prefork;
@@ -76,7 +76,7 @@ has riap_client            => (             # Perinci::Access object
         );
     });
 
-my $json = JSON->new->allow_nonref;
+my $json = JSON::MaybeXS->new->allow_nonref;
 
 sub BUILD {
     my ($self) = @_;
@@ -485,7 +485,7 @@ Perinci::Access::Simple::Server::Socket - Implement Riap::Simple server over soc
 
 =head1 VERSION
 
-This document describes version 0.23 of Perinci::Access::Simple::Server::Socket (from Perl distribution Perinci-Access-Simple-Server), released on 2015-09-12.
+This document describes version 0.24 of Perinci::Access::Simple::Server::Socket (from Perl distribution Perinci-Access-Simple-Server), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -630,21 +630,13 @@ doesn't have to load modules separately (= inefficient).
 
 Write access log entry.
 
-=head1 SEE ALSO
-
-L<Riap::Simple>, L<Riap>, L<Rinci>
-
-L<peri-sockserve>, simple command-line interface for this module.
-
-L<Perinci::Access::Simple::Client>, L<Perinci::Access>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Access-Simple-Server>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-Simple-Server>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-Simple-Server>.
 
 =head1 BUGS
 
@@ -654,13 +646,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Riap::Simple>, L<Riap>, L<Rinci>
+
+L<peri-sockserve>, simple command-line interface for this module.
+
+L<Perinci::Access::Simple::Client>, L<Perinci::Access>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
